# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/anonstore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/anonstore.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n#zsearch_definitions/anonstore.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\"\xa7\x01\n\x0b\x43\x65rtificate\x12\x0e\n\x06sha1fp\x18\x01 \x01(\x0c\x12\x10\n\x08sha256fp\x18\x02 \x01(\x0c\x12\x0b\n\x03raw\x18\x03 \x01(\x0c\x12\x0e\n\x06parsed\x18\x04 \x01(\t\x12\x0f\n\x07parents\x18\x05 \x03(\x0c\x12\x14\n\x0cNSSRootStore\x18\x06 \x01(\x08\x12\x1a\n\x12MicrosoftRootStore\x18\x07 \x01(\x08\x12\x16\n\x0e\x41ppleRootStore\x18\x08 \x01(\x08\"N\n\x13RSACryptographicKey\x12\x0f\n\x07modulus\x18\x01 \x01(\x0c\x12\x10\n\x08\x65xponent\x18\x02 \x01(\x0c\x12\t\n\x01p\x18\x03 \x01(\x0c\x12\t\n\x01q\x18\x04 \x01(\x0c\"L\n\x13\x44SACryptographicKey\x12\t\n\x01p\x18\x01 \x01(\x0c\x12\t\n\x01q\x18\x02 \x01(\x0c\x12\t\n\x01g\x18\x03 \x01(\x0c\x12\t\n\x01y\x18\x04 \x01(\x0c\x12\t\n\x01x\x18\x05 \x01(\x0c\"K\n\x13\x45\x43\x43\x43ryptographicKey\x12\r\n\x05\x63urve\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x0c\x12\t\n\x01y\x18\x03 \x01(\x0c\x12\x0f\n\x07private\x18\x04 \x01(\x0c\"\xc8\x02\n\x10\x43ryptographicKey\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.zsearch.CryptographicKey.KeyType\x12+\n\x03rsa\x18\x02 \x01(\x0b\x32\x1c.zsearch.RSACryptographicKeyH\x00\x12+\n\x03\x64sa\x18\x03 \x01(\x0b\x32\x1c.zsearch.DSACryptographicKeyH\x00\x12+\n\x03\x65\x63\x63\x18\x04 \x01(\x0b\x32\x1c.zsearch.ECCCryptographicKeyH\x00\x12\x0e\n\x06\x62roken\x18\x05 \x01(\x08\x12\x0e\n\x06\x63ommon\x18\x06 \x01(\x08\x12\x0e\n\x06\x64\x65\x62ian\x18\x07 \x01(\x08\"?\n\x07KeyType\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x07\n\x03RSA\x10\x02\x12\x07\n\x03\x44SA\x10\x03\x12\x07\n\x03\x45\x43\x43\x10\x04\x42\x0b\n\tkey_oneof\"\xde\x02\n\x0f\x41nonymousRecord\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x07\x12\x0f\n\x07scan_id\x18\x03 \x01(\r\x12\x10\n\x08\x65xported\x18\x04 \x01(\x08\x12\'\n\x08userdata\x18\x05 \x01(\x0b\x32\x15.zsearch.UserdataAtom\x12\x0e\n\x04\x64\x61ta\x18\x06 \x01(\tH\x00\x12\x12\n\x08raw_data\x18\x07 \x01(\x0cH\x00\x12+\n\x0b\x63\x65rtificate\x18\x08 \x01(\x0b\x32\x14.zsearch.CertificateH\x00\x12(\n\x03key\x18\t \x01(\x0b\x32\x19.zsearch.CryptographicKeyH\x00\x12\x1d\n\x02\x61s\x18\n \x01(\x0b\x32\x0f.zsearch.ASAtomH\x00\x12$\n\x08metadata\x18\x0e \x03(\x0b\x32\x12.zsearch.Metadatum\x12\x0c\n\x04tags\x18\x0f \x03(\tB\x0c\n\noneof_data\"\xbe\x02\n\x0e\x41nonymousDelta\x12\x35\n\ndelta_type\x18\x01 \x01(\x0e\x32!.zsearch.AnonymousDelta.DeltaType\x12\x37\n\x0b\x64\x65lta_scope\x18\x02 \x01(\x0e\x32\".zsearch.AnonymousDelta.DeltaScope\x12(\n\x06record\x18\x03 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\":\n\tDeltaType\x12\x0f\n\x0b\x44T_RESERVED\x10\x00\x12\r\n\tDT_UPDATE\x10\x01\x12\r\n\tDT_DELETE\x10\x02\"V\n\nDeltaScope\x12\x12\n\x0eSCOPE_RESERVED\x10\x00\x12\x13\n\x0fSCOPE_NO_CHANGE\x10\x01\x12\r\n\tSCOPE_NEW\x10\x02\x12\x10\n\x0cSCOPE_UPDATE\x10\x03\x62\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CRYPTOGRAPHICKEY_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='zsearch.CryptographicKey.KeyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RSA', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DSA', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ECC', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=740,
  serialized_end=803,
)
_sym_db.RegisterEnumDescriptor(_CRYPTOGRAPHICKEY_KEYTYPE)

_ANONYMOUSDELTA_DELTATYPE = _descriptor.EnumDescriptor(
  name='DeltaType',
  full_name='zsearch.AnonymousDelta.DeltaType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DT_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_UPDATE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DT_DELETE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1344,
  serialized_end=1402,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTATYPE)

_ANONYMOUSDELTA_DELTASCOPE = _descriptor.EnumDescriptor(
  name='DeltaScope',
  full_name='zsearch.AnonymousDelta.DeltaScope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCOPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NO_CHANGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_NEW', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCOPE_UPDATE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1404,
  serialized_end=1490,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSDELTA_DELTASCOPE)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='zsearch.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha1fp', full_name='zsearch.Certificate.sha1fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Certificate.sha256fp', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw', full_name='zsearch.Certificate.raw', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='zsearch.Certificate.parsed', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='zsearch.Certificate.parents', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='NSSRootStore', full_name='zsearch.Certificate.NSSRootStore', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='MicrosoftRootStore', full_name='zsearch.Certificate.MicrosoftRootStore', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='AppleRootStore', full_name='zsearch.Certificate.AppleRootStore', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=250,
)


_RSACRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='RSACryptographicKey',
  full_name='zsearch.RSACryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulus', full_name='zsearch.RSACryptographicKey.modulus', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exponent', full_name='zsearch.RSACryptographicKey.exponent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='p', full_name='zsearch.RSACryptographicKey.p', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='q', full_name='zsearch.RSACryptographicKey.q', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=330,
)


_DSACRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='DSACryptographicKey',
  full_name='zsearch.DSACryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='zsearch.DSACryptographicKey.p', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='q', full_name='zsearch.DSACryptographicKey.q', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g', full_name='zsearch.DSACryptographicKey.g', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='zsearch.DSACryptographicKey.y', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='zsearch.DSACryptographicKey.x', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=408,
)


_ECCCRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='ECCCryptographicKey',
  full_name='zsearch.ECCCryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='curve', full_name='zsearch.ECCCryptographicKey.curve', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='x', full_name='zsearch.ECCCryptographicKey.x', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='zsearch.ECCCryptographicKey.y', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private', full_name='zsearch.ECCCryptographicKey.private', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=485,
)


_CRYPTOGRAPHICKEY = _descriptor.Descriptor(
  name='CryptographicKey',
  full_name='zsearch.CryptographicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.CryptographicKey.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rsa', full_name='zsearch.CryptographicKey.rsa', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dsa', full_name='zsearch.CryptographicKey.dsa', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ecc', full_name='zsearch.CryptographicKey.ecc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broken', full_name='zsearch.CryptographicKey.broken', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='zsearch.CryptographicKey.common', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debian', full_name='zsearch.CryptographicKey.debian', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRYPTOGRAPHICKEY_KEYTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key_oneof', full_name='zsearch.CryptographicKey.key_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=488,
  serialized_end=816,
)


_ANONYMOUSRECORD = _descriptor.Descriptor(
  name='AnonymousRecord',
  full_name='zsearch.AnonymousRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousRecord.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.AnonymousRecord.timestamp', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scan_id', full_name='zsearch.AnonymousRecord.scan_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exported', full_name='zsearch.AnonymousRecord.exported', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='zsearch.AnonymousRecord.userdata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.AnonymousRecord.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw_data', full_name='zsearch.AnonymousRecord.raw_data', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate', full_name='zsearch.AnonymousRecord.certificate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.AnonymousRecord.key', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as', full_name='zsearch.AnonymousRecord.as', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='zsearch.AnonymousRecord.metadata', index=10,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='zsearch.AnonymousRecord.tags', index=11,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_data', full_name='zsearch.AnonymousRecord.oneof_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=819,
  serialized_end=1169,
)


_ANONYMOUSDELTA = _descriptor.Descriptor(
  name='AnonymousDelta',
  full_name='zsearch.AnonymousDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta_type', full_name='zsearch.AnonymousDelta.delta_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta_scope', full_name='zsearch.AnonymousDelta.delta_scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.AnonymousDelta.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANONYMOUSDELTA_DELTATYPE,
    _ANONYMOUSDELTA_DELTASCOPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1172,
  serialized_end=1490,
)

_CRYPTOGRAPHICKEY.fields_by_name['type'].enum_type = _CRYPTOGRAPHICKEY_KEYTYPE
_CRYPTOGRAPHICKEY.fields_by_name['rsa'].message_type = _RSACRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.fields_by_name['dsa'].message_type = _DSACRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.fields_by_name['ecc'].message_type = _ECCCRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY_KEYTYPE.containing_type = _CRYPTOGRAPHICKEY
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['rsa'])
_CRYPTOGRAPHICKEY.fields_by_name['rsa'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['dsa'])
_CRYPTOGRAPHICKEY.fields_by_name['dsa'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof'].fields.append(
  _CRYPTOGRAPHICKEY.fields_by_name['ecc'])
_CRYPTOGRAPHICKEY.fields_by_name['ecc'].containing_oneof = _CRYPTOGRAPHICKEY.oneofs_by_name['key_oneof']
_ANONYMOUSRECORD.fields_by_name['userdata'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_ANONYMOUSRECORD.fields_by_name['certificate'].message_type = _CERTIFICATE
_ANONYMOUSRECORD.fields_by_name['key'].message_type = _CRYPTOGRAPHICKEY
_ANONYMOUSRECORD.fields_by_name['as'].message_type = zsearch__definitions_dot_common__pb2._ASATOM
_ANONYMOUSRECORD.fields_by_name['metadata'].message_type = zsearch__definitions_dot_common__pb2._METADATUM
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['data'])
_ANONYMOUSRECORD.fields_by_name['data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['raw_data'])
_ANONYMOUSRECORD.fields_by_name['raw_data'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['certificate'])
_ANONYMOUSRECORD.fields_by_name['certificate'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['key'])
_ANONYMOUSRECORD.fields_by_name['key'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSRECORD.oneofs_by_name['oneof_data'].fields.append(
  _ANONYMOUSRECORD.fields_by_name['as'])
_ANONYMOUSRECORD.fields_by_name['as'].containing_oneof = _ANONYMOUSRECORD.oneofs_by_name['oneof_data']
_ANONYMOUSDELTA.fields_by_name['delta_type'].enum_type = _ANONYMOUSDELTA_DELTATYPE
_ANONYMOUSDELTA.fields_by_name['delta_scope'].enum_type = _ANONYMOUSDELTA_DELTASCOPE
_ANONYMOUSDELTA.fields_by_name['record'].message_type = _ANONYMOUSRECORD
_ANONYMOUSDELTA_DELTATYPE.containing_type = _ANONYMOUSDELTA
_ANONYMOUSDELTA_DELTASCOPE.containing_type = _ANONYMOUSDELTA
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['RSACryptographicKey'] = _RSACRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['DSACryptographicKey'] = _DSACRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['ECCCryptographicKey'] = _ECCCRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['CryptographicKey'] = _CRYPTOGRAPHICKEY
DESCRIPTOR.message_types_by_name['AnonymousRecord'] = _ANONYMOUSRECORD
DESCRIPTOR.message_types_by_name['AnonymousDelta'] = _ANONYMOUSDELTA

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATE,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Certificate)
  ))
_sym_db.RegisterMessage(Certificate)

RSACryptographicKey = _reflection.GeneratedProtocolMessageType('RSACryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _RSACRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RSACryptographicKey)
  ))
_sym_db.RegisterMessage(RSACryptographicKey)

DSACryptographicKey = _reflection.GeneratedProtocolMessageType('DSACryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _DSACRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.DSACryptographicKey)
  ))
_sym_db.RegisterMessage(DSACryptographicKey)

ECCCryptographicKey = _reflection.GeneratedProtocolMessageType('ECCCryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _ECCCRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ECCCryptographicKey)
  ))
_sym_db.RegisterMessage(ECCCryptographicKey)

CryptographicKey = _reflection.GeneratedProtocolMessageType('CryptographicKey', (_message.Message,), dict(
  DESCRIPTOR = _CRYPTOGRAPHICKEY,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CryptographicKey)
  ))
_sym_db.RegisterMessage(CryptographicKey)

AnonymousRecord = _reflection.GeneratedProtocolMessageType('AnonymousRecord', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSRECORD,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousRecord)
  ))
_sym_db.RegisterMessage(AnonymousRecord)

AnonymousDelta = _reflection.GeneratedProtocolMessageType('AnonymousDelta', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSDELTA,
  __module__ = 'zsearch_definitions.anonstore_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousDelta)
  ))
_sym_db.RegisterMessage(AnonymousDelta)


import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)
